@@ -1,9 +1,8 @@
+# frozen_string_literal: true
 require 'parallel_tests/rspec/failures_logger'
 
 class ParallelTests::RSpec::SummaryLogger < ParallelTests::RSpec::LoggerBase
-  unless RSPEC_2
-    RSpec::Core::Formatters.register self, :dump_failures
-  end
+  RSpec::Core::Formatters.register self, :dump_failures unless RSPEC_2
 
   def dump_failures(*args)
     lock_output { super }
