@@ -67,7 +67,7 @@ describe ParallelTests::RSpec::RuntimeLogger do
 
     def write(file, content)
       FileUtils.mkdir_p(File.dirname(file))
-      File.open(file, 'w') { |f| f.write content }
+      File.write(file, content)
     end
 
     it "logs shared examples into the running files" do
@@ -90,7 +90,7 @@ describe ParallelTests::RSpec::RuntimeLogger do
 
       system(
         { 'TEST_ENV_NUMBER' => '1' },
-        "rspec spec -I #{Bundler.root.join("lib")} --format ParallelTests::RSpec::RuntimeLogger --out runtime.log 2>&1"
+        "rspec", "spec", "-I", Bundler.root.join("lib").to_s, "--format", "ParallelTests::RSpec::RuntimeLogger", "--out", "runtime.log"
       ) || raise("nope")
 
       result = File.read("runtime.log")
@@ -122,7 +122,7 @@ describe ParallelTests::RSpec::RuntimeLogger do
 
       system(
         { 'TEST_ENV_NUMBER' => '1' },
-        "rspec spec -I #{Bundler.root.join("lib")} --format ParallelTests::RSpec::RuntimeLogger --out runtime.log 2>&1"
+        "rspec", "spec", "-I", Bundler.root.join("lib").to_s, "--format", "ParallelTests::RSpec::RuntimeLogger", "--out", "runtime.log"
       ) || raise("nope")
 
       result = File.read("runtime.log")
