@@ -352,7 +352,7 @@ describe ParallelTests::Test::Runner do
       end
     end
 
-    it "doesn't find bakup files with the same name as test files" do
+    it "doesn't find backup files with the same name as test files" do
       with_files(['a/x_test.rb', 'a/x_test.rb.bak']) do |root|
         expect(call(["#{root}/"])).to eq(
           [
@@ -581,6 +581,14 @@ describe ParallelTests::Test::Runner do
       end
     end
 
+    it "allows using TEST_ENV_NUMBER in arguments" do
+      run_with_file("puts ARGV") do |path|
+        result = call(["ruby", path, "$TEST_ENV_NUMBER"], 1, 4, {})
+        expect(result[:stdout].chomp).to eq '2'
+        expect(result[:exit_status]).to eq 0
+      end
+    end
+
     describe "rspec seed" do
       it "includes seed when provided" do
         run_with_file("puts 'Run options: --seed 555'") do |path|
@@ -602,7 +610,7 @@ describe ParallelTests::Test::Runner do
     def call(*args)
       base = ["ruby", "-Ilib:test", "test/minitest/test_minitest_unit.rb"]
       result = ParallelTests::Test::Runner.command_with_seed([*base, *args], "555")
-      result[base.length..-1]
+      result[base.length..]
     end
 
     it "adds the randomized seed" do
